---
releasedAt: 2025-04-08T00:00:00.000Z
writtenAt: 2025-04-08T00:00:00.000Z
---

안녕하세요, 파트너 정산 자동화팀입니다.<br />
파트너에게 지급할 금액을 계산할 때, **정산금액을 어떤 기준으로 해석할지** 선택할 수 있는 기능이 새롭게 추가되었습니다.<br />
이번 개선을 통해 **공급가액 기준 또는 합계금액 기준** 중 선택하여, 더욱 유연하고 명확한 지급 기준을 설정할 수 있습니다.<br />
또한, **일괄지급 시 통장 메모(적요)** 기능이 더 눈에 잘 띄고 쉽게 설정되도록 **UI가 개선**되었습니다.<br />
자주 사용하는 통장 메모는 한 번만 등록해두면, 지급 시 자동으로 적용되니 한번 설정해보시는 것 어떨까요? <br />

⚠️ **\[중요] 업데이트**로 인한 **API 변경사항**도 하단에서 꼭 확인해주세요.

---

## 🔍 주요 기능 안내

### 1. **정산 세부 금액 확인 가능 (공급가액 / 면세금액 / 부가세액)**

지난 업데이트에서 지원된 면세금액을 활용하여 공급가액 / 면세금액 / 부가세액을 분리하여 확인 확정할 수 있습니다.

정산금액은 다음 세 가지 항목으로 구분되어 확인 가능합니다:

- **공급가액**: 과세 대상 금액(세전)
- **면세금액**: 면세 대상 금액
- **부가세액**: 공급가액 기준으로 자동 계산된 세금

> 이 정보를 기반으로, 지급 금액 계산의 기준을 선택할 수 있습니다.

### 2. **지급금액 산정 기준 선택 가능 (정산금액 취급 기준 설정)**

정산정책 등록 시 지급금액을 계산할 때 어떤 기준으로 정산금액을 사용할지 선택할 수 있습니다.

|설정값               |**설명**                                                                           |**지급금액 계산 방식**                 |
|---------------------|-----------------------------------------------------------------------------------|---------------------------------------|
|**합계금액** (기본값)|정산금액을 `공급가액 + 면세금액 + 부가세`로 간주하여 지급                          |지급금액 = 정산금액                    |
|**공급가액**         |정산금액을 `공급가액 + 면세금액`으로 간주하고, <br /> 부가세는 별도로 계산되어 지급|지급금액 = 정산금액 × 1.1 (부가세 별도)|

---

## ✅ 화면 변경 안내

### 1. 정산 규칙 **설정 페이지 리뉴얼**

- 기존의 **정산 정책 관리 > 정산 규칙 탭**이 **‘설정’ 탭**으로 변경되었습니다.
- 구조: **정산 정책 설정** / **지급 금액 설정** 으로 구성
- **정산 금액 취급 기준** 설정이 추가되어, 정산 금액 계산 시 **부가세 포함 여부**를 설정할 수 있습니다.

(관련 이미지 첨부)

### 2. **지급 내역 관리 - 테이블 항목 추가**

- 지급 내역 테이블에 아래 항목들이 추가되어 설정 탭에서 선택한 **지급 기준**을 한눈에 확인할 수 있습니다.
  - `원천징수세액 차감 여부`: 차감 / 미차감
  - `정산 금액 취급 기준`: 합계 금액 / 공급가액

(관련 이미지 첨부)

---

### 3. **일괄지급 기본 설정 UI 개선**

- 일괄지급 시 **통장 적요 메모**를 미리 등록하면, 매번 자동으로 적용됩니다.
- 이 편리한 기능의 활용도를 높이기 위해 UI 디자인이 개선되었습니다.

> ✨ 한 번만 설정해두면, 반복 작업 없이 간편하게 지급 메모가 적용됩니다.

(관련 이미지 첨부)

---

## ⚠️ API 변경 안내

사전 고지된 deprecated 속성들이 삭제되었습니다.

### \[중요] 정산 다건 조회 API

> GET /platform/partner-settlements

- `items.type` 이 `ORDER` 혹은 `ORDER_CANCEL` 인 경우 `amount` 객체 내에
  - `supply` 가 삭제되었습니다. `paymentSupply` 로 대체 사용해주시길 바랍니다.
  - `taxFree` 가 삭제되었습니다. `paymentTaxFree` 로 대체 사용해주시길 바랍니다.

### \[중요] 정산 상세 관련 API

> **관련 API**
>
> \- GET /platform/transfer-summaries
>
> \- GET /platform/transfers/{id}
>
> \- POST /platform/transfers/order
>
> \- POST /platform/transfers/order-cancel

- `type` 이 `ORDER` 혹은 `ORDER_CANCEL` 인 경우 `amount` 객체 내에
  - `supply` 가 삭제되었습니다. `paymentSupply` 로 대체 사용해주시길 바랍니다.
  - `taxFree` 가 삭제되었습니다. `paymentTaxFree` 로 대체 사용해주시길 바랍니다.

### 지급 다건 조회 API

> GET /platform/payouts

- 200 응답 시  `items` 배열 객체 내
  - 지급 금액 계산 관련 옵션
    - `deductWht` 원천징수세액 차감 여부 추가되었습니다.
    - `failReason` 지급실패사유 추가되었습니다.
    - `settlementAmountType` 정산금액 취급 기준이 추가되었습니다.

  - 확정 세부 금액
    - `supplyAmount` 확정 공급가액 추가되었습니다.
    - `vatAmount` 확정 부가세액 추가되었습니다.
    - `taxFreeAmont` 확정 면세금액 추가되었습니다.

---

감사합니다.

파트너정산 자동화 팀 드림
